using System.ComponentModel;
using System.Xml.Serialization;

namespace EQIA.EQIDL
{
    [TypeConverter(typeof(ScrollbarDrawTemplateConverter))]
    public partial class ScrollbarDrawTemplate : Class
    {
        #region Members

        private string myMiddleTextureInfo;
        private ButtonDrawTemplate myUpButton, myDownButton;
        private FrameTemplate myThumb;
        private RGB myMiddleTint;

        #endregion

        #region Properties

        [XmlElement("MiddleTextureInfo", IsNullable = false)]
        [Browsable(true), Description("Filename for an image file whose entirety is the pattern for for the scroll area of the scrollbar")]
        [NotifyParentProperty(true)]
        public string MiddleTextureInfo { get { return myMiddleTextureInfo; } set { myMiddleTextureInfo = value; } }

        [XmlElement("UpButton", IsNullable = false)]
        [Browsable(true), Description("Template that defines the art for this scrollbar's up button")]
        [NotifyParentProperty(true)]
        public ButtonDrawTemplate UpButton { get { return myUpButton; } set { myUpButton = value; } }

        [XmlElement("DownButton", IsNullable = false)]
        [Browsable(true), Description("Template that defines the art for this scrollbar's down button")]
        [NotifyParentProperty(true)]
        public ButtonDrawTemplate DownButton { get { return myDownButton; } set { myDownButton = value; } }

        [XmlElement("Thumb", IsNullable = false)]
        [Browsable(true), Description("Template that defines the art for this scrollbar's scroll box")]
        [NotifyParentProperty(true)]
        public FrameTemplate Thumb { get { return myThumb; } set { myThumb = value; } }

        [XmlElement(ElementName = "MiddleTint", IsNullable = false)]
        [Browsable(true), Description("Tint to apply to the scroll area texture")]
        [NotifyParentProperty(true)]
        public RGB MiddleTint { get { return myMiddleTint; } set { myMiddleTint = value; } }

        #endregion

        #region Creation

        public ScrollbarDrawTemplate()
            : this(null)
        {
        }

        public ScrollbarDrawTemplate(EQInterface eqInterface)
            : base(eqInterface)
        {
        }

        #endregion

        #region Deserialization

        protected override void SetProperties(object obj)
        {
            base.SetProperties(obj);

            ScrollbarDrawTemplate temp_ScrollbarDrawTemplate = obj as ScrollbarDrawTemplate;
            if (temp_ScrollbarDrawTemplate != null)
            {
                MiddleTextureInfo = temp_ScrollbarDrawTemplate.MiddleTextureInfo;
                UpButton = temp_ScrollbarDrawTemplate.UpButton;
                DownButton = temp_ScrollbarDrawTemplate.DownButton;
                Thumb = temp_ScrollbarDrawTemplate.Thumb;
                MiddleTint = temp_ScrollbarDrawTemplate.MiddleTint;
            }
        }

        #endregion
    }

    public class ScrollbarDrawTemplateConverter : ExpandableObjectConverter
    {
        public override object ConvertTo(ITypeDescriptorContext context, System.Globalization.CultureInfo culture, object value, System.Type destinationType)
        {
            return (destinationType == typeof(string)) ? string.Empty : base.ConvertTo(context, culture, value, destinationType);
        }
    }
}
